PeerGate

Struct PeerGate 

pub struct PeerGate { /* private fields */ }
Per-name concurrency limiter.

Implementations

Source

impl PeerGate

pub fn new() -> Self

Construct fresh.

pub fn acquire(&mut self, name: &str, n: u32) -> bool

Try to acquire one permit. Returns false if the current inflight count for name is at or above n, else increments the counter and returns true.

pub fn release(&mut self, name: &str)

Release one permit.

pub fn inflight(&self, name: &str) -> u32

Read current inflight count for the named gate.