roles_for_component

Function roles_for_component 

pub fn roles_for_component(
    type_name: &str,
) -> impl Iterator<Item = ComponentRole> + use<'_>
Iterate every role binding for a given component type. Used by Node::ensure_ready to compute the bitflags + by introspection tools to discover what roles a struct implements.